#!/bin/csh -f
#
#                PROJECT_DIR
#     _______________|_______________
#    |         |           |         |
#   NMR      AMBER       CYANA     RESULTS
#
# - load cyana2.1 pdb files in project/cyana2.1/batch1/ 
#   (saved from cyana2.1 with "write_all min1-")
# - leap topology and crd files saved in current directory
# - grep out the Q pseudoatoms and linkers
# - change HIS bound Zn to HIE (or HID)
# - use the amber program protonate
# - change CYS- (bound to Zn) to CYM
# - change CYSZ (bound to Zn) to CYM

##############################################
# User Defined Variables
set cyana_dir=../../cyana/1.noe-hb-aco-vdw1

##############################################

  foreach file ($cyana_dir/*-???.pdb)
# set file=$cyana_dir/min1-001.pdb  # Use for Testing

##############################################
# Remove Pseudoatoms and Substitute Linker by TER

    sed '/Q1  NL/s/^.*$/TER/' $file  > temp1.pdb

    grep -v '   1      ' temp1.pdb | \
    grep -v '   2      '      | \
    grep -v '   3      '      | \
    grep -v '   4      '      | \
    grep -v ' PL '            | \
    grep -v ' LP '            | \
    grep -v ' NL '            | \
    grep -v ' LN '            | \
    grep -v ' LL5 '           | \
    grep -v Q                         > temp2.pdb

####################
# PREPARE THE RNA

# Remove Molecule Identifier and Rename RNA
    perl -pi -e 's|RADEA| RA  |g' temp2.pdb
    perl -pi -e 's|RAD\+A| RA  |g' temp2.pdb
    perl -pi -e 's|RGUAA| RG  |g' temp2.pdb
    perl -pi -e 's|RCYTA| RC  |g' temp2.pdb
    perl -pi -e 's|URA A| RU  |g' temp2.pdb
    perl -pi -e 's| A |   |g' temp2.pdb

# Add 5 and 3 to 5' and 5' RNA residues
    perl -pi -e 's|RC   283|RC5   283|g' temp2.pdb
    perl -pi -e 's|RG   298|RG3   298|g' temp2.pdb
    perl -pi -e 's|RC   683|RC5   683|g' temp2.pdb
    perl -pi -e 's|RG   698|RG3   698|g' temp2.pdb

# - Remove the Extra appended 5' Phosphate
    grep -v 'P    RC5' temp2.pdb | \
    grep -v 'OP1  RC5'           | \
    grep -v 'OP2  RC5'             > temp2a.pdb

# - Remove Protons from RNA and Protein
    grep -v ' H ' temp2a.pdb      | \
    grep -v ' H\([0-9]\)'         | \
    grep -v ' \([0-9]\)H'         | \
    grep -v ' H. '                | \
    grep -v ' H.\([0-9]\) '       | \
    grep -v ' HO2'                  >  temp3.pdb

# - Renumber RNA Residue numbers and fix RNA atom names
     pymol2amber-RNA.pl -s 275 276 305 temp3.pdb > temp3a.pdb
     pymol2amber-RNA.pl -s 675 676 705 temp3a.pdb > temp4.pdb

#####################################################################
## PREPARE THE PROTEIN
#
## ZN is attached to HIS 23 NE2 and HIS 44 NE2 (rename HID)
#    perl -pi -e 's|HIS     23|HID     23|g' temp4.pdb
#    perl -pi -e 's|HIS     44|HID     44|g' temp4.pdb
#    
## ZN attached to CYS- residues (rename CYSX)
#    perl -pi -e 's|CYS-A|CYX  |g' temp4.pdb
#    perl -pi -e 's|CYSZA|CYX  |g' temp4.pdb
#
### Append Zn to the end of the file and remove extra Zn atoms
#    ./UMBC-appendZN.pl temp4.pdb > temp6.pdb
#
########################
# Renumber all atom numbers
#    UMBC-renumberpdb.pl -a temp6.pdb > temp7.pdb 
#
     UMBC-renumberpdb.pl -a temp4.pdb > temp7.pdb
#####################################################################
#### tleap 
  
    cp temp7.pdb for-leap.pdb
 
# EDIT  leaprc.ff99.NC to generate .top and .crd files
     tleap -s -f leaprc.ff99.rna

# Rename and save the .top and .crd files in the current directory
     mv amber.top ${file:r:t}.top
     mv amber.crd ${file:r:t}.crd
     ambpdb -aatm -p ${file:r:t}.top < ${file:r:t}.crd > ${file:r:t}.pdb

     cp ./*001.pdb ./amber.pdb
     cp ./*001.crd ./amber.crd
 
     /bin/rm -f temp*
end
