#!/bin/csh -f
#                PROJECT_DIR
#     _______________|_______________
#    |         |           |         |
#   NMR      AMBER       CYANA     RESULTS
#                 _________|_______
#                |         |       |
#            PROTEIN      RNA   PROTEIN-RNA
#
###############################################
# PROJECT DEPENDENT VARIABLES
set startmol1=283
set endmol1=298
set startmol2=683
set endmol2=698
##############################################

#NOTE:  Dont need 5 and 3 resnames

set sub1=`expr $startmol1 - 1`
set sub2=`expr $startmol2 - $endmol2 + $startmol2 - 2`


#############################################
### NOE RESTRAINTS
### Combine cyana NOE Upper Limit Files
#    (NOE and hbond upper limit restraints)

    cat ../../cyana/b-noe.upl \
        > ./cyana-noe.upl

     cat ../../cyana/b-hb.upl \
         > ./cyana-hb.upl

    cat ../../cyana/b-pp.upl \
        > ./cyana-pp.upl

    cat ../../cyana/b-plan.lol \
        > ./cyana-plan.lol

    cat ../../cyana/b-pp.lol \
        > ./cyana-pp.lol

# - Define amber.pdb input file
     set AMB_PDB=../1.prep/amber.pdb

# - Define atom map file for makeDIST_RST
    set MAP=./map-HHMI.DG-AMBER

#############################################
# - NOE RESTRAINTS

   cp ./cyana-noe.upl temp.upl

# - Rename RNA residues
    perl -pi -e 's|RADE| RA |g' temp.upl
    perl -pi -e 's|RAD\+| RA |g' temp.upl
    perl -pi -e 's|RGUA| RG |g' temp.upl
    perl -pi -e 's|RCYT| RC |g' temp.upl
    perl -pi -e 's|URA | RU |g' temp.upl

# - Renumber upl.amb file from cyana (not necessary for HIV-NC)
    renumberupl.pl -$sub1 $startmol1 $endmol1 ./temp.upl > moda.upl
    renumberupl.pl -$sub2 $startmol2 $endmol2 ./moda.upl > mod.upl

# - Make the Amber NOE input file
    makeDIST_RST -upb ./mod.upl -pdb $AMB_PDB -map $MAP -rst noe.RST

##############################################
# - HYDROGEN BOND UPPER LIMITS
# - Clean up the H-bond Upper Limit file
    cp cyana-hb.upl ./temphb.upl
# - Rename RNA residues
    perl -pi -e 's|RADE| RA |g' temphb.upl
    perl -pi -e 's|RAD\+| RA |g' temphb.upl
    perl -pi -e 's|RGUA| RG |g' temphb.upl
    perl -pi -e 's|RCYT| RC |g' temphb.upl
    perl -pi -e 's|URA | RU |g' temphb.upl

# - Renumber upl.amb file from cyana (not necessary for HIV-NC)
    renumberupl.pl -$sub1 $startmol1 $endmol1 ./temphb.upl > temphba.upl
    renumberupl.pl -$sub2 $startmol2 $endmol2 ./temphba.upl > temphbb.upl

# - Make the Amber Hbond input file
    makeDIST_RST -upb ./temphbb.upl -pdb $AMB_PDB -map $MAP -rst hb.RST

##############################################
## - PHOSPHATE UPPER LIMITS
#    cp ./cyana-pp.upl ./temppp.upl
#
## - Rename RNA residues
#    perl -pi -e 's|RADE| RA |g' temppp.upl
#    perl -pi -e 's|RAD\+| RA |g' temppp.upl
#    perl -pi -e 's|RGUA| RG |g' temppp.upl
#    perl -pi -e 's|RCYT| RC |g' temppp.upl
#    perl -pi -e 's|URA | RU |g' temppp.upl
#
## - Renumber upl.amb file from cyana (not necessary for HIV-NC)
#    renumberupl.pl -$sub1 $startmol1 $endmol1 ./temppp.upl > tempppa.upl
#    renumberupl.pl -$sub2 $startmol2 $endmol2 ./tempppa.upl > tempppb.upl
#
## - Make the Amber Hbond input file
#    makeDIST_RST -upb ./tempppb.upl -pdb $AMB_PDB -map $MAP -rst pp.RST
#
############################################
## -  LOWER LIMIT BASE PAIR PLANARITY
## - Clean up the Cyana Lower Limit file
#    cp ./cyana-plan.lol temp.lol
#
## - Rename RNA residues
#    perl -pi -e 's|RADE| RA |g' temp.lol
#    perl -pi -e 's|RAD\+| RA |g' temp.lol
#    perl -pi -e 's|RGUA| RG |g' temp.lol
#    perl -pi -e 's|RCYT| RC |g' temp.lol
#    perl -pi -e 's|URA | RU |g' temp.lol
#
## - Renumber lol.amb file from cyana (not necessary for HIV-NC)
#     UMBC-makeual.pl -$sub1 $startmol1 $endmol1 1.0 ./temp.lol > moda.lol
#     UMBC-makeual.pl -$sub2 $startmol2 $endmol2 1.0 ./moda.lol > mod.lol
#
## - Make the Amber Lower Limit file
#    makeDIST_RST -ual ./mod.lol -pdb $AMB_PDB -map $MAP -rst plan.RST
#    perl -pi -e 's|rk2\=20\.0|rk2\=80\.0|g' plan.RST
#    perl -pi -e 's|rk3\=20\.0|rk3\=80\.0|g' plan.RST
#
##########################################
# - Make the Amber Chirality restraint file
    makeCHIR_RST.UMBC $AMB_PDB ./chirality.RST

#################################################
### COMBINE DISANG RESTRAINTS

    cat chirality.RST hb.RST > DISANG-chir-hb.RST
    cat noe.RST chirality.RST hb.RST > DISANG-noe-chir-hb.RST

### Clean up
   /bin/rm temp* mod* test* cyana*
#  /bin/rm noe.RST chirality.RST hb.RST

echo
echo Done
echo
