#!/bin/bash
##############################################
# Execute in background with:
# at -f [script to be executed] now + 2 minutes
# at -f [script to be executed] 10:30
###############################################
  CUR_LOC=${PWD}
  sandermpi=/mfslab/software/amber/SL_v11/exe/sander.MPI
  export PATH="/common/mpich2-mx/macports/bin:/opt/local/bin/:${PATH}"
  mpdallexit &> /dev/null
  mpdboot --ncpus=4 -n 40 -m /common/mpich2-mx/macports/bin/mpd -f /hpc_tools/cluster/allnodes
###############################################

# USER DEFINED VARIABLES
    PREP_DIR=../../1.prep
    RST_DIR=../../2.RST
    NAME=min1
    FIRST=1                  # First Residue for fixed position refinement
    LAST=32                  # Last Residue for fixed position refinement
    DIP_RST=DIP0.RST
    CSA_RST=RCSA0.RST
    DWT_HIGH=0.1             # DIP weight (high)
    DWT_LOW=0.00001          # DIP weight (low)
    CWT_HIGH=0.1             # CSA weight (high)
    CWT_LOW=0.00001          # CSA weight (low)
    STRUCTURES=20            # maximum 20 

    ELE=1.0                  # Electrostatic weight

    DISnoNOE=DISANG-chir-hb.RST
    DISall=DISANG-noe-chir-hb.RST

    DIR0=0.min               # Brief minimization to eliminate bad contacts
    DIR1=1.noNOE-0K
    DIR2=2.NOE-0K
    DIR3=3.NOE-50K

    mkdir $DIR0
    mkdir $DIR1
    mkdir $DIR2
    mkdir $DIR3

########################################
########################################

STARTJOB=1
ENDJOB=$STRUCTURES
CURRENTJOB=$STARTJOB
INPUT=0
unset DISPLAY

echo -n "Starting Script at:  "
date
echo ""

while [ $CURRENTJOB -le $ENDJOB ]
do
  if [ $CURRENTJOB -lt 10 ]
  then
     INPUT=00$CURRENTJOB
  else
     INPUT=0$CURRENTJOB
  fi

###################################
N=0 #  MINIMIZE CYANA Structures
###################################

    NSTLIM=1000

############################
 eval OUT_DIR='$'DIR$N
 cat << eof > $OUT_DIR/amber-${INPUT}.in

 &cntrl
    maxcyc=$NSTLIM,
    imin=1, igb=1, ntb=0,
    nmropt=0,
    ntmin=1, ncyc=100,
    scee=1.2, dielc=1,
    pencut=0.1, ntpr=50,
    cut=12.0,
 &end

eof
#############

##########################################
N=1  # 1.noNOE-0K
##########################################

    NSTLIM=400000
    TEMP_HIGH=0.0
    DIS_RST=$DISnoNOE
    DWT=$DWT_LOW
    CWT=$CWT_LOW
    NTR=0
    SPRING=0.1       # Used only for NTR=1
    FREEZES=false    # false or true to freeze the alignment tensor

##############
 eval OUT_DIR='$'DIR$N
 cp $RST_DIR/$DIS_RST $OUT_DIR/DISANG.RST.${INPUT}
#cp $RST_DIR/$DIP_RST $OUT_DIR/$DIP_RST.${INPUT}
#cp $RST_DIR/$CSA_RST $OUT_DIR/$CSA_RST.${INPUT}
#changedwt.pl $OUT_DIR/$DIP_RST.${INPUT} $DWT
#changecwt.pl $OUT_DIR/$CSA_RST.${INPUT} $CWT
#freezes.pl $OUT_DIR/$DIP_RST.${INPUT} $FREEZES
 let "step1b=$NSTLIM/10" "step2b=$NSTLIM/4" "step3b=$NSTLIM/2"
 let "step2a=$step1b+1" "step3a=$step2b+1" "step4a=$step3b+1"

 cat << eof > $OUT_DIR/amber-${INPUT}.in

 &cntrl
    nstlim=$NSTLIM,
    imin=0, nmropt=1,
    pencut=0.1,
    ipnlty=1, scee=1.2, igb=1,
    ntpr=500, ntwx=500, ntwr=500,
    tempi=0.0,
    ntt=1, cut=12, ntc=2, vlimit=10., ntb=0,
    dt=0.0002,
    ntx=1, irest=0,
    iscale=5, scalm=300.0,
    ntr=$NTR,
 &end

 &ewald
   eedmeth=5,
 &end

# Simulated annealing protocol
 &wt type='TEMP0', istep1=      0, istep2=$step1b, value1=0.0, value2=$TEMP_HIGH, &end
 &wt type='TEMP0', istep1=$step2a, istep2=$step2b, value1=$TEMP_HIGH, value2=$TEMP_HIGH, &end
 &wt type='TEMP0', istep1=$step3a, istep2=$step3b, value1=$TEMP_HIGH, value2=0.0, &end
 &wt type='TEMP0', istep1=$step4a, istep2=$NSTLIM, value1=0.0, value2=0.0, &end
 &wt type='TAUTP', istep1=      0, istep2=$NSTLIM, value1=0.2, value2=0.2, &end
 &wt type='ELEC',  istep1=      0, istep2=$NSTLIM, value1=$ELE, value2=$ELE, &end
 &wt type='REST', istep1=      0, istep2=$step1b, value1=0.0, value2=2.0, &end
 &wt type='REST', istep1=$step2a, istep2=$step2b, value1=2.0, value2=2.0, &end
 &wt type='REST', istep1=$step3a, istep2=$step3b, value1=2.0, value2=1.0, &end
 &wt type='REST', istep1=$step4a, istep2=$NSTLIM, value1=1.0, value2=1.0, &end

 &wt type='END' &end
LISTOUT=POUT
DISANG=$OUT_DIR/DISANG.RST.${INPUT}

Fix RNA atom positions and calculate alignment tensor
 $SPRING
 RES $FIRST $LAST
END
END
eof
####################
#DIPOLE=$OUT_DIR/$DIP_RST.${INPUT}
#CSA=$OUT_DIR/$CSA_RST.${INPUT}

##########################################
N=2  # 2.NOE-0K
##########################################

    NSTLIM=400000
    TEMP_HIGH=0.0
    DIS_RST=$DISall
    DWT=$DWT_LOW
    CWT=$CWT_LOW
    NTR=0
    SPRING=0.1       # Used only for NTR=1
    FREEZES=false    # false or true to freeze the alignment tensor

##############
 eval OUT_DIR='$'DIR$N
 cp $RST_DIR/$DIS_RST $OUT_DIR/DISANG.RST.${INPUT}
#cp $RST_DIR/$DIP_RST $OUT_DIR/$DIP_RST.${INPUT}
#cp $RST_DIR/$CSA_RST $OUT_DIR/$CSA_RST.${INPUT}
#changedwt.pl $OUT_DIR/$DIP_RST.${INPUT} $DWT
#changecwt.pl $OUT_DIR/$CSA_RST.${INPUT} $CWT
#freezes.pl $OUT_DIR/$DIP_RST.${INPUT} $FREEZES
 let "step1b=$NSTLIM/10" "step2b=$NSTLIM/4" "step3b=$NSTLIM/2"
 let "step2a=$step1b+1" "step3a=$step2b+1" "step4a=$step3b+1"

 cat << eof > $OUT_DIR/amber-${INPUT}.in

 &cntrl
    nstlim=$NSTLIM,
    imin=0, nmropt=1,
    pencut=0.1,
    ipnlty=1, scee=1.2, igb=1,
    ntpr=500, ntwx=500, ntwr=500,
    tempi=0.0,
    ntt=1, cut=12, ntc=2, vlimit=10., ntb=0,
    dt=0.0002,
    ntx=1, irest=0,
    iscale=5, scalm=300.0,
    ntr=$NTR,
 &end

 &ewald
   eedmeth=5,
 &end

# Simulated annealing protocol
 &wt type='TEMP0', istep1=      0, istep2=$step1b, value1=0.0, value2=$TEMP_HIGH, &end
 &wt type='TEMP0', istep1=$step2a, istep2=$step2b, value1=$TEMP_HIGH, value2=$TEMP_HIGH, &end
 &wt type='TEMP0', istep1=$step3a, istep2=$step3b, value1=$TEMP_HIGH, value2=0.0, &end
 &wt type='TEMP0', istep1=$step4a, istep2=$NSTLIM, value1=0.0, value2=0.0, &end
 &wt type='TAUTP', istep1=      0, istep2=$NSTLIM, value1=0.2, value2=0.2, &end
 &wt type='ELEC',  istep1=      0, istep2=$NSTLIM, value1=$ELE, value2=$ELE, &end
 &wt type='REST', istep1=      0, istep2=$step1b, value1=0.0, value2=2.0, &end
 &wt type='REST', istep1=$step2a, istep2=$step2b, value1=2.0, value2=2.0, &end
 &wt type='REST', istep1=$step3a, istep2=$step3b, value1=2.0, value2=1.0, &end
 &wt type='REST', istep1=$step4a, istep2=$NSTLIM, value1=1.0, value2=1.0, &end

 &wt type='END' &end
LISTOUT=POUT
DISANG=$OUT_DIR/DISANG.RST.${INPUT}

Fix RNA atom positions and calculate alignment tensor
 $SPRING
 RES $FIRST $LAST
END
END
eof
####################
#DIPOLE=$OUT_DIR/$DIP_RST.${INPUT}
#CSA=$OUT_DIR/$CSA_RST.${INPUT}

##########################################
N=3  # 3.NOE-50K
##########################################

    NSTLIM=400000
    TEMP_HIGH=50.0
    DIS_RST=$DISall
    DWT=$DWT_LOW
    CWT=$CWT_LOW
    NTR=0
    SPRING=0.1       # Used only for NTR=1
    FREEZES=false    # false or true to freeze the alignment tensor

##############
 eval OUT_DIR='$'DIR$N
 cp $RST_DIR/$DIS_RST $OUT_DIR/DISANG.RST.${INPUT}
#cp $RST_DIR/$DIP_RST $OUT_DIR/$DIP_RST.${INPUT}
#cp $RST_DIR/$CSA_RST $OUT_DIR/$CSA_RST.${INPUT}
#changedwt.pl $OUT_DIR/$DIP_RST.${INPUT} $DWT
#changecwt.pl $OUT_DIR/$CSA_RST.${INPUT} $CWT
#freezes.pl $OUT_DIR/$DIP_RST.${INPUT} $FREEZES
 let "step1b=$NSTLIM/10" "step2b=$NSTLIM/4" "step3b=$NSTLIM/2"
 let "step2a=$step1b+1" "step3a=$step2b+1" "step4a=$step3b+1"

 cat << eof > $OUT_DIR/amber-${INPUT}.in

 &cntrl
    nstlim=$NSTLIM,
    imin=0, nmropt=1,
    pencut=0.1,
    ipnlty=1, scee=1.2, igb=1,
    ntpr=500, ntwx=500, ntwr=500,
    tempi=0.0,
    ntt=1, cut=12, ntc=2, vlimit=10., ntb=0,
    dt=0.0002,
    ntx=1, irest=0,
    iscale=5, scalm=300.0,
    ntr=$NTR,
 &end

 &ewald
   eedmeth=5,
 &end

# Simulated annealing protocol
 &wt type='TEMP0', istep1=      0, istep2=$step1b, value1=0.0, value2=$TEMP_HIGH, &end
 &wt type='TEMP0', istep1=$step2a, istep2=$step2b, value1=$TEMP_HIGH, value2=$TEMP_HIGH, &end
 &wt type='TEMP0', istep1=$step3a, istep2=$step3b, value1=$TEMP_HIGH, value2=0.0, &end
 &wt type='TEMP0', istep1=$step4a, istep2=$NSTLIM, value1=0.0, value2=0.0, &end
 &wt type='TAUTP', istep1=      0, istep2=$NSTLIM, value1=0.2, value2=0.2, &end
 &wt type='ELEC',  istep1=      0, istep2=$NSTLIM, value1=$ELE, value2=$ELE, &end
 &wt type='REST', istep1=      0, istep2=$step1b, value1=0.0, value2=2.0, &end
 &wt type='REST', istep1=$step2a, istep2=$step2b, value1=2.0, value2=2.0, &end
 &wt type='REST', istep1=$step3a, istep2=$step3b, value1=2.0, value2=1.0, &end
 &wt type='REST', istep1=$step4a, istep2=$NSTLIM, value1=1.0, value2=1.0, &end

 &wt type='END' &end
LISTOUT=POUT
DISANG=$OUT_DIR/DISANG.RST.${INPUT}

Fix RNA atom positions and calculate alignment tensor
 $SPRING
 RES $FIRST $LAST
END
END
eof
####################
#DIPOLE=$OUT_DIR/$DIP_RST.${INPUT}
#CSA=$OUT_DIR/$CSA_RST.${INPUT}


###############################
  ((CURRENTJOB += 1))
done
###############################
nodes="/hpc_tools/cluster"    ### machine file location
nodesetNo=1			  ### the node list file

STARTJOB=1
ENDJOB=$STRUCTURES
CURRENTJOB=$STARTJOB
INPUT=0
unset DISPLAY

echo -n "Starting Script at:  "
date
echo ""

while [ $CURRENTJOB -le $ENDJOB ]
do
  if [ $CURRENTJOB -lt 10 ]
  then
     INPUT=00$CURRENTJOB
  else
     INPUT=0$CURRENTJOB
  fi
####################################

cd $CUR_LOC  \
\
\
&& IN_DIR=$PREP_DIR \
&& OUT_DIR=$DIR0 \
&& mpirun -machinefile ${nodes}/nodeset2${nodesetNo} -np 8 $sandermpi -O \
   -i $OUT_DIR/amber-${INPUT}.in \
   -p $IN_DIR/$NAME-${INPUT}.top \
   -c $IN_DIR/$NAME-${INPUT}.crd \
   -o $OUT_DIR/$NAME-${INPUT}.out \
   -r $OUT_DIR/$NAME-${INPUT}.rst \
   -ref $IN_DIR/$NAME-${INPUT}.crd \
 \
&& ambpdb -p $PREP_DIR/$NAME-${INPUT}.top \
          < $OUT_DIR/$NAME-${INPUT}.rst \
          > $OUT_DIR/$NAME-${INPUT}.pdb \
\
&& IN_DIR=$DIR0 \
&& OUT_DIR=$DIR1 \
 \
&& mpirun -machinefile ${nodes}/nodeset2${nodesetNo} -np 8 $sandermpi -O \
   -i $OUT_DIR/amber-${INPUT}.in \
   -p $PREP_DIR/$NAME-${INPUT}.top \
   -c $IN_DIR/$NAME-${INPUT}.rst \
   -o $OUT_DIR/$NAME-${INPUT}.out \
   -r $OUT_DIR/$NAME-${INPUT}.rst \
   -x $OUT_DIR/$NAME-${INPUT}.trj \
   -ref $IN_DIR/$NAME-${INPUT}.rst \
 \
&& ambpdb -p $PREP_DIR/$NAME-${INPUT}.top \
          < $OUT_DIR/$NAME-${INPUT}.rst \
          > $OUT_DIR/$NAME-${INPUT}.pdb \
\
&& IN_DIR=$DIR0 \
&& OUT_DIR=$DIR2 \
&& mpirun -machinefile ${nodes}/nodeset2${nodesetNo} -np 8 $sandermpi -O \
   -i $OUT_DIR/amber-${INPUT}.in \
   -p $PREP_DIR/$NAME-${INPUT}.top \
   -c $IN_DIR/$NAME-${INPUT}.rst \
   -o $OUT_DIR/$NAME-${INPUT}.out \
   -r $OUT_DIR/$NAME-${INPUT}.rst \
   -x $OUT_DIR/$NAME-${INPUT}.trj \
   -ref $IN_DIR/$NAME-${INPUT}.rst \
 \
&& ambpdb -p $PREP_DIR/$NAME-${INPUT}.top \
          < $OUT_DIR/$NAME-${INPUT}.rst \
          > $OUT_DIR/$NAME-${INPUT}.pdb \
\
&& IN_DIR=$DIR0 \
&& OUT_DIR=$DIR3 \
&& mpirun -machinefile ${nodes}/nodeset2${nodesetNo} -np 8 $sandermpi -O \
   -i $OUT_DIR/amber-${INPUT}.in \
   -p $PREP_DIR/$NAME-${INPUT}.top \
   -c $IN_DIR/$NAME-${INPUT}.rst \
   -o $OUT_DIR/$NAME-${INPUT}.out \
   -r $OUT_DIR/$NAME-${INPUT}.rst \
   -x $OUT_DIR/$NAME-${INPUT}.trj \
   -ref $IN_DIR/$NAME-${INPUT}.rst \
 \
&& ambpdb -p $PREP_DIR/$NAME-${INPUT}.top \
          < $OUT_DIR/$NAME-${INPUT}.rst \
          > $OUT_DIR/$NAME-${INPUT}.pdb \
\
\
 &


## next set of calculations (8 CPUs each)
## after the fifth set, goes back to set 1
  ((nodesetNo += 1))
  ((CURRENTJOB += 1))
sleep 3
done
exit
